@@ -1,11 +1,13 @@
 """Utilitarian Python ORM for Postgres, backed by asyncpg, Pydantic, and PyPika"""
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
+# Provided for convenience
 from pypika import Order
 
 from .core import *
 from .exceptions import *
+from .fields import *
 from .table import *
 from .types import *
 from .utils import *
